import { Consola, ConsolaOptions } from 'consola';
/**
 * Used to set the logging level.
 *
 * @example Explicitly set the level of an imported package beyond the current runtime level.
 * ```ts
 * import { LogLevel } from '@genesislcap/foundation-logger';
 * import { logger as myPackageLogger } from 'my-package';
 * myPackageLogger.level = LogLevel.Error;
 * ```
 *
 * @public
 */
export { LogLevel, logType } from 'consola';
/**
 * Options for creating a logger.
 * @public
 */
export interface LoggerOptions extends ConsolaOptions {
}
/**
 * A logger that extends the `Consola` logger.
 *
 * @remarks
 * This logger is part of the package's API but may still be subject to changes and improvements.
 *
 * @public
 */
export interface Logger extends Consola {
    /**
     * A logger method for deprecated symbols.
     *
     * @remarks
     * Pair with a deprecated tag. See {@link https://tsdoc.org/pages/tags/deprecated/} for more information.
     *
     * @example
     * ```ts
     * logger.deprecated('someSymbol');
     * ```
     *
     * @example With a custom instruction and target removal version.
     * ```ts
     * logger.deprecated('routeButtons', 'Use the default slot instead.', '20.0.0');
     * ```
     *
     * @param symbol - The deprecated symbol.
     * @param instruction - An optional alternative instruction. Defaults to `Consult docs for better alternative.`
     * @param removalVersionTarget - An optional target removal version number.
     */
    deprecated(symbol: string, instruction?: string, removalVersionTarget?: string): void;
}
/**
 * A logger that extends the `Consola` logger.
 * @public
 */
export interface Logger extends Consola {
}
/**
 * The default logger options.
 * @public
 */
export declare const defaultLoggerOptions: LoggerOptions;
/**
 * Creates a logger with the given name and options.
 *
 * @example Create a logger in my-package/utils.
 * ```ts
 * import { createLogger } from '@genesislcap/foundation-logger';
 * export const logger = createLogger('my-package');
 * ```
 *
 * @example Using the logger within my-package.
 * ```ts
 * import { logger } from '../utils';
 * logger.debug(`Data retrieved from ${resourceName}`);
 * logger.info(this.toggled ? 'On' : 'Off');
 * logger.warn('Not available in this browser.');
 * ```
 *
 * @param name - The name to give the logger.
 * @param options - The options to use when creating the logger.
 * @returns The resulting logger.
 * @public
 */
export declare function createLogger(name: string, options?: LoggerOptions): Logger;
//# sourceMappingURL=logger.d.ts.map